@@ -6,11 +6,13 @@ from prelude_parser._prelude_parser import _parse_flat_file_to_pandas_dict
 
 try:
     import polars as pl
-except ImportError:  # pragma: no cover
-    raise ImportError("prelude-parser must be installed with the polars or all extra to use pandas")
+except ImportError as e:  # pragma: no cover
+    raise ImportError(
+        "prelude-parser must be installed with the polars or all extra to use pandas"
+    ) from e
 
 
-def to_dataframe(xml_file: str | Path) -> pl.DataFrame:
+def to_dataframe(xml_file: str | Path, *, short_names: bool = False) -> pl.DataFrame:
     """Parse a Prelude flat XML file into a Polars DataFrame.
 
     This works for Prelude flat XML files that were exported with the "write tables to seperate
@@ -18,6 +20,7 @@ def to_dataframe(xml_file: str | Path) -> pl.DataFrame:
 
     Args:
         xml_file: The path to the XML file to parser.
+        short_names: Set to True if short names were used in the export.
 
     Returns:
         A Polars DataFrame the data from the XML file.
@@ -26,5 +29,5 @@ def to_dataframe(xml_file: str | Path) -> pl.DataFrame:
         >>> from prelude_parser.polars import to_dataframe
         >>> df = to_dataframe("physical_examination.xml")
     """
-    data = _parse_flat_file_to_pandas_dict(xml_file)
+    data = _parse_flat_file_to_pandas_dict(xml_file, short_names=short_names)
     return pl.from_dict(data)
